@@ -6,7 +6,7 @@ from urllib.parse import urlparse
 import pandas as pd
 from elasticsearch import Elasticsearch
 from pandas.io.json import json_normalize
-from pydantic import Field, BaseModel, SecretStr
+from pydantic import BaseModel, Field, SecretStr
 
 from toucan_connectors.common import nosql_apply_parameters_to_query
 from toucan_connectors.toucan_connector import ToucanConnector, ToucanDataSource
@@ -137,7 +137,7 @@ class ElasticsearchConnector(ToucanConnector):
                 h['port'] = host.port
 
             if host.username or host.password:
-                h['http_auth'] = f'{host.username}:{host.password}'
+                h['http_auth'] = f'{host.username}:{host.password.get_secret_value()}'
             if host.headers:
                 h['headers'] = host.headers
             connection_params.append(h)
