@@ -2,7 +2,7 @@ import pandas as pd
 import pyodbc
 from pydantic import Field, constr
 
-from toucan_connectors.common import convert_to_printf_templating_style, convert_to_qmark_paramstyle
+from toucan_connectors.common import pandas_read_sql
 from toucan_connectors.toucan_connector import ToucanConnector, ToucanDataSource
 
 
@@ -35,8 +35,8 @@ class OdbcConnector(ToucanConnector):
     def _retrieve_data(self, datasource: OdbcDataSource) -> pd.DataFrame:
 
         connection = pyodbc.connect(self.connection_string, **self.get_connection_params())
-        query = convert_to_printf_templating_style(datasource.query)
-        converted_query, ordered_values = convert_to_qmark_paramstyle(query, datasource.parameters)
-        df = pd.read_sql(converted_query, con=connection, params=ordered_values)
+        df = pandas_read_sql(
+            datasource.query, con=connection, params=datasource.parameters, convert_to_qmark=True
+        )
         connection.close()
         return df
