@@ -167,8 +167,20 @@ def decorate_func_with_retry(func):
     return get_func_and_retry
 
 
-def is_oauth2_connector(cls):
-    return hasattr(cls, '_auth_flow') and getattr(cls, '_auth_flow') == 'oauth2'
+def get_oauth2_configuration(cls):
+    """Return a tuple indicating if the connector is an oauth2 connector
+    and in this case, where can the credentials be located
+    """
+    oauth2_enabled = hasattr(cls, '_auth_flow') and getattr(cls, '_auth_flow') == 'oauth2'
+    oauth2_credentials_location = None
+    if hasattr(cls, '_oauth_trigger'):
+        oauth2_credentials_location = getattr(cls, '_oauth_trigger')
+    return oauth2_enabled, oauth2_credentials_location
+
+
+# Deprecated
+def is_oauth2_connector(cls) -> bool:
+    return get_oauth2_configuration(cls)[0]  # pragma: no cover
 
 
 def needs_sso_credentials(cls) -> bool:
@@ -214,16 +226,17 @@ class ToucanConnector(BaseModel, metaclass=ABCMeta):
     the `_retry_on` class attribute in your concrete connector class.
     """
 
-    name: str
+    name: str = Field(...)
     retry_policy: Optional[RetryPolicy] = RetryPolicy()
     _retry_on: Iterable[Type[BaseException]] = ()
-    type: str = None
-    secrets_storage_version = '1'
+    type: str = Field(None)
+    secrets_storage_version = Field('1', **{'ui.hidden': True})
 
     class Config:
         extra = 'forbid'
         validate_assignment = True
 
+    @classmethod
     def __init_subclass__(cls):
         try:
             cls.data_source_model = cls.__fields__.pop('data_source_model').type_
